@@ -7,7 +7,7 @@ import numpy
 
 import rasterio
 from rasterio.warp import (
-    reproject, RESAMPLING, transform_geom, transform, transform_bounds,
+    reproject, Resampling, transform_geom, transform, transform_bounds,
     calculate_default_transform)
 
 
@@ -131,9 +131,9 @@ def test_transform_bounds_densify_out_of_bounds():
 
 def test_calculate_default_transform():
     target_transform = Affine(
-        0.0028956983577810586, 0.0, -78.95864996545055,
-        0.0, -0.0028956983577810586, 25.550873767433984
-    )
+        0.0028535715391804096, 0.0, -78.95864996545055,
+        0.0, -0.0028535715391804096, 25.550873767433984)
+
     with rasterio.drivers():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
             wgs84_crs = {'init': 'EPSG:4326'}
@@ -141,14 +141,13 @@ def test_calculate_default_transform():
                 src.crs, wgs84_crs, src.width, src.height, *src.bounds)
 
             assert dst_transform.almost_equals(target_transform)
-            assert width == 824
-            assert height == 686
+            assert width == 835
+            assert height == 696
 
 
 def test_calculate_default_transform_single_resolution():
     with rasterio.drivers():
         with rasterio.open('tests/data/RGB.byte.tif') as src:
-            l, b, r, t = src.bounds
             target_resolution = 0.1
             target_transform = Affine(
                 target_resolution, 0.0, -78.95864996545055,
@@ -209,7 +208,7 @@ def test_reproject_ndarray():
             src_crs=src.crs,
             dst_transform=DST_TRANSFORM,
             dst_crs=dst_crs,
-            resampling=RESAMPLING.nearest)
+            resampling=Resampling.nearest)
         assert (out > 0).sum() == 438146
 
 
@@ -227,7 +226,7 @@ def test_reproject_epsg():
             src_crs=src.crs,
             dst_transform=DST_TRANSFORM,
             dst_crs=dst_crs,
-            resampling=RESAMPLING.nearest)
+            resampling=Resampling.nearest)
         assert (out > 0).sum() == 438146
 
 
@@ -246,7 +245,7 @@ def test_reproject_out_of_bounds():
             src_crs=src.crs,
             dst_transform=DST_TRANSFORM,
             dst_crs=dst_crs,
-            resampling=RESAMPLING.nearest)
+            resampling=Resampling.nearest)
         assert not out.any()
 
 
@@ -271,9 +270,36 @@ def test_reproject_nodata():
             dst_nodata=nodata
         )
 
-        assert (out == 1).sum() == 4461
+        assert (out == 1).sum() == 6215
         assert (out == nodata).sum() == (params.dst_width *
-                                         params.dst_height - 4461)
+                                         params.dst_height - 6215)
+
+
+def test_reproject_nodata_nan():
+    params = default_reproject_params()
+    nodata = 215
+
+    with rasterio.drivers():
+        source = numpy.ones((params.width, params.height), dtype=numpy.float32)
+        out = numpy.zeros((params.dst_width, params.dst_height),
+                          dtype=source.dtype)
+        out.fill(120)  # Fill with arbitrary value
+
+        reproject(
+            source,
+            out,
+            src_transform=params.src_transform,
+            src_crs=params.src_crs,
+            src_nodata=numpy.nan,
+            dst_transform=params.dst_transform,
+            dst_crs=params.dst_crs,
+            dst_nodata=numpy.nan
+        )
+
+        assert (out == 1).sum() == 6215
+        assert numpy.isnan(out).sum() == (params.dst_width *
+                                         params.dst_height - 6215)
+
 
 
 def test_reproject_dst_nodata_default():
@@ -299,9 +325,9 @@ def test_reproject_dst_nodata_default():
             dst_crs=params.dst_crs
         )
 
-        assert (out == 1).sum() == 4461
+        assert (out == 1).sum() == 6215
         assert (out == 0).sum() == (params.dst_width *
-                                    params.dst_height - 4461)
+                                    params.dst_height - 6215)
 
 
 def test_reproject_invalid_dst_nodata():
@@ -392,7 +418,7 @@ def test_reproject_multi():
             src_crs=src.crs,
             dst_transform=DST_TRANSFORM,
             dst_crs=dst_crs,
-            resampling=RESAMPLING.nearest)
+            resampling=Resampling.nearest)
     assert destin.any()
 
 
@@ -527,10 +553,30 @@ def test_transform_geom():
         'EPSG:3373', 
         'EPSG:4326', 
         geom, 
-        antimeridian_cutting=True, 
+        antimeridian_cutting=True,
         antimeridian_offset=0)
     assert result['type'] == 'MultiPolygon'
     assert len(result['coordinates']) == 2
 
     result = transform_geom('EPSG:3373', 'EPSG:4326',  geom,  precision=1)
     assert int(result['coordinates'][0][0][0] * 10) == -1778
+
+
+def test_reproject_invalid_resampling():
+    # An invalid resampling number fails.
+    with rasterio.drivers():
+        with rasterio.open('tests/data/RGB.byte.tif') as src:
+            source = src.read_band(1)
+
+        dst_crs = {'init': 'EPSG:32619'}
+        out = numpy.empty(src.shape, dtype=numpy.uint8)
+        with pytest.raises(ValueError) as exc_info:
+            reproject(
+                source,
+                out,
+                src_transform=src.transform,
+                src_crs=src.crs,
+                dst_transform=DST_TRANSFORM,
+                dst_crs=dst_crs,
+                resampling=99)
+            assert "99 is not a valid Resampling" in exc_info.value.message
